==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/es.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generar códigos de respaldo",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Los códigos de respaldo han sido generados. Ha usado {{used}} de {{total}}.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son sus códigos de respaldo. Por favor guardelos y/o imprimalos ya que no podrá optenerlos nuevamente después.",
    "Save backup codes" : "Guardar códigos de respaldo",
    "Print backup codes" : "Imprimir códigos de respaldo",
    "Regenerate backup codes" : "Regenerar códigos de respaldo",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenera los códigos de respaldo automaticamente invalidara los antiguos.",
    "An error occurred while generating your backup codes" : "Ha ocurrido un error mientras se generaban los códigos de respaldo.",
    "Nextcloud backup codes" : "Códigos de respaldo de Nextcloud",
    "Two-factor authentication" : "Autenticación en dos pasos",
    "You successfully logged in using two-factor authentication (%1$s)" : "Te has identificado correctamente usando la autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de identificación usando autenticación en dos pasos ha fallado (%1$s)",
    "You created two-factor backup codes for your account" : "Has creado códigos de respaldo de dos pasos para tu cuenta",
    "Backup code" : "Código de respaldo",
    "Use backup code" : "Usar código de respaldo",
    "Second-factor backup codes" : "Codigo de copia de seguridad de segundo-factor"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/es.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "Generate backup codes" : "Generar códigos de respaldo",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Los códigos de respaldo han sido generados. Ha usado {{used}} de {{total}}.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Estos son sus códigos de respaldo. Por favor guardelos y/o imprimalos ya que no podrá optenerlos nuevamente después.",
    "Save backup codes" : "Guardar códigos de respaldo",
    "Print backup codes" : "Imprimir códigos de respaldo",
    "Regenerate backup codes" : "Regenerar códigos de respaldo",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si regenera los códigos de respaldo automaticamente invalidara los antiguos.",
    "An error occurred while generating your backup codes" : "Ha ocurrido un error mientras se generaban los códigos de respaldo.",
    "Nextcloud backup codes" : "Códigos de respaldo de Nextcloud",
    "Two-factor authentication" : "Autenticación en dos pasos",
    "You successfully logged in using two-factor authentication (%1$s)" : "Te has identificado correctamente usando la autenticación en dos pasos (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de identificación usando autenticación en dos pasos ha fallado (%1$s)",
    "You created two-factor backup codes for your account" : "Has creado códigos de respaldo de dos pasos para tu cuenta",
    "Backup code" : "Código de respaldo",
    "Use backup code" : "Usar código de respaldo",
    "Second-factor backup codes" : "Códigos de respaldo de dos-factores"
},
"nplurals=2; plural=(n != 1);");
